@@ -15,7 +15,7 @@ lstRpl <- rbind(c("<84>",   "<93>",   "<c4>",   "<d6>",   "<dc>",   "<df>",   "<
 lstMnf <- list(mnfVer = c("Manifest-Version",        "1.0"),
                datVer = c("Data-Archive-Version",    "1.0.2"),
                jmvVer = c("jamovi-Archive-Version",  "11.0"),
-               crtStr = c("Created-By"));
+               crtStr = c("Created-By"))
 
 # the next lines are dealing with storing the global and the data column attributes (that go into
 # metadata.json inside the .omv-file; the currently defined defaults are in accordance with
@@ -32,7 +32,7 @@ grpMta <- paste0("^", paste(c(names(mtaGlb), names(mtaFld)), collapse = "$|^"),
 # dimensions and existence of data frames) and normalizing the file name
 
 #            jamovi  CSV   TSV     Rdata           RDS   SPSS           Stata  SAS
-vldExt <- c("omv",  "csv", "tsv", "rdata", "rda", "rds", "sav", "zsav", "dta", "sas7bdat", "sd2", "sd7", "xpt", "stx", "stc");
+vldExt <- c("omv",  "csv", "tsv", "rdata", "rda", "rds", "sav", "zsav", "dta", "sas7bdat", "sd2", "sd7", "xpt", "stx", "stc")
 
 # REMEMBER: requires the full file name, NOT the directory
 chkDir <- function(fleNme = "", wrtPrm = TRUE) {
@@ -71,7 +71,8 @@ chkFle <- function(fleNme = "", fleCnt = "", isZIP = FALSE) {
             stop(sprintf("File \"%s\" not found.", fleNme))
         }
     } else if (isZIP) {
-        hdrStr <- readBin(tmpHdl <- file(fleNme, "rb"), "character"); close(tmpHdl);
+        hdrStr <- readBin(tmpHdl <- file(fleNme, "rb"), "character")
+        close(tmpHdl)
         # only "PK\003\004" is considered, not "PK\005\006" (empty ZIP) or "PK\007\008" (spanned [over several files])
         if (! hdrStr == "PK\003\004\024") {
             stop(sprintf("File \"%s\" has not the correct file format (is not a ZIP archive).", basename(fleNme)))
@@ -106,11 +107,11 @@ fmtFlI <- function(fleInp = c(), minLng = 1, maxLng = Inf, excExt = "") {
     # if fleOut is empty, fleInp is used with its file extension replaced with ".omv"
     if (length(fleInp) < minLng || length(fleInp) > maxLng) {
         stop(sprintf("The fleInp-argument is supposed to be a character vector with a minimal length of %.0f and a maximal length of %.0f (current length is %.0f).%s",
-                     minLng, maxLng, length(fleInp), ifelse(length(fleInp) > maxLng, "\n  If you would like to process several files, call the function individually for each.", "")));
+                     minLng, maxLng, length(fleInp), ifelse(length(fleInp) > maxLng, "\n  If you would like to process several files, call the function individually for each.", "")))
     }
-    fleInp <- unname(sapply(fleInp, nrmFle));
-    all(sapply(fleInp, chkFle));
-    all(sapply(fleInp, chkExt, setdiff(vldExt, excExt)));
+    fleInp <- unname(sapply(fleInp, nrmFle))
+    all(sapply(fleInp, chkFle))
+    all(sapply(fleInp, chkExt, setdiff(vldExt, excExt)))
     fleInp
 }
 
@@ -120,7 +121,7 @@ fmtFlO <- function(fleOut = "", fleInp = "", rplExt = "") {
     } else if (length(fleInp) == 1 && nzchar(fleInp[1])) {
         sub(paste0(".", tools::file_ext(fleInp[1])), rplExt, fleInp[1])
     } else {
-        stop(paste0("Either fleOut needs to be given as a valid non-empty file name or a single entry in fleInp where the extension is replaced with: \"", rplExt, "\"."));
+        stop(paste0("Either fleOut needs to be given as a valid non-empty file name or a single entry in fleInp where the extension is replaced with: \"", rplExt, "\"."))
     }
 }
 
@@ -128,7 +129,7 @@ fmtFlO <- function(fleOut = "", fleInp = "", rplExt = "") {
 # get function arguments and adjust them / select those valid for the current function call
 
 adjArg <- function(fcnNme = c(), dflArg = list(), varArg = list(), fxdArg = c()) {
-    chgArg <- setdiff(intersect(fcnArg(fcnNme), names(varArg)), fxdArg);
+    chgArg <- setdiff(intersect(fcnArg(fcnNme), names(varArg)), fxdArg)
     c(dflArg[setdiff(names(dflArg), chgArg)], varArg[chgArg])
 }
 
@@ -138,7 +139,7 @@ fcnArg <- function(fcnNme = c()) {
     } else if (is.character(fcnNme) && length(fcnNme) == 2) {
         eval(parse(text = paste0("formalArgs(getS3method(\"", fcnNme[1], "\", \"", fcnNme[2], "\"))")))
     } else {
-        stop("The argument to fcnArg must be a character (vector) with 1 or 2 elements.");
+        stop("The argument to fcnArg must be a character (vector) with 1 or 2 elements.")
     }
 }
 
@@ -148,15 +149,15 @@ fcnArg <- function(fcnNme = c()) {
 # dimensions and existence of data frames) and normalizing the file name
 
 #            jamovi  CSV   TSV     Rdata           RDS   SPSS           Stata  SAS
-vldExt <- c("omv",  "csv", "tsv", "rdata", "rda", "rds", "sav", "zsav", "dta", "sas7bdat", "sd2", "sd7", "xpt", "stx", "stc");
+vldExt <- c("omv",  "csv", "tsv", "rdata", "rda", "rds", "sav", "zsav", "dta", "sas7bdat", "sd2", "sd7", "xpt", "stx", "stc")
 
 # REMEMBER: requires the full file name, NOT the directory
 chkDir <- function(fleNme = "", wrtPrm = TRUE) {
     if (! utils::file_test("-d", dirname(fleNme))) {
-        stop(sprintf("Directory (%s) doesn\'t exist.", dirname(fleNme)));
+        stop(sprintf("Directory (%s) doesn\'t exist.", dirname(fleNme)))
     }
     if (file.access(dirname(fleNme), mode = 2) != 0) {
-        stop(sprintf("The directory (%s) exists, but you don\'t have writing permissions in that directory.", dirname(fleNme)));
+        stop(sprintf("The directory (%s) exists, but you don\'t have writing permissions in that directory.", dirname(fleNme)))
     }
     TRUE
 }
@@ -164,17 +165,17 @@ chkDir <- function(fleNme = "", wrtPrm = TRUE) {
 chkDtF <- function(dtaFrm = NULL, minSze = c(1, 1)) {
     if (length(minSze) != 2) minSze <- rep(minSze[1], 2)
     if (is.null(dtaFrm) || ! is.data.frame(dtaFrm) || length(dim(dtaFrm)) != 2) {
-        stop("Input data are either not a data frame or have incorrect (only one or more than two) dimensions.");
+        stop("Input data are either not a data frame or have incorrect (only one or more than two) dimensions.")
     } else if (any(dim(dtaFrm) < minSze)) {
         stop(sprintf("The %s dimension of the input data frame has not the required size (%d < %d).",
-                     ifelse(which(dim(dtaFrm) < minSze)[1] == 1, "first", "second"), dim(dtaFrm)[dim(dtaFrm) < minSze][1], minSze[dim(dtaFrm) < minSze][1]));
+                     ifelse(which(dim(dtaFrm) < minSze)[1] == 1, "first", "second"), dim(dtaFrm)[dim(dtaFrm) < minSze][1], minSze[dim(dtaFrm) < minSze][1]))
     }
     TRUE
 }
 
 chkExt <- function(fleNme = "", extNme = c("")) {
     if (! hasExt(fleNme, extNme)) {
-        stop(sprintf("File name (%s) contains an unsupported file extension (%s).", basename(fleNme), paste(paste0(".", extNme[tools::file_ext(fleNme) != extNme]), collapse = ", ")));
+        stop(sprintf("File name (%s) contains an unsupported file extension (%s).", basename(fleNme), paste(paste0(".", extNme[tools::file_ext(fleNme) != extNme]), collapse = ", ")))
     }
     TRUE
 }
@@ -182,24 +183,25 @@ chkExt <- function(fleNme = "", extNme = c("")) {
 chkFle <- function(fleNme = "", fleCnt = "", isZIP = FALSE) {
     if (! utils::file_test("-f", fleNme)) {
         if (nchar(fleCnt) > 0) {
-            stop(sprintf("File \"%s\" doesn\'t contain the file \"%s\".", fleCnt, fleNme));
+            stop(sprintf("File \"%s\" doesn\'t contain the file \"%s\".", fleCnt, fleNme))
         } else {
-            stop(sprintf("File \"%s\" not found.", fleNme));
+            stop(sprintf("File \"%s\" not found.", fleNme))
         }
     } else if (isZIP) {
-        hdrStr <- readBin(tmpHdl <- file(fleNme, "rb"), "character"); close(tmpHdl);
+        hdrStr <- readBin(tmpHdl <- file(fleNme, "rb"), "character")
+        close(tmpHdl)
         # only "PK\003\004" is considered, not "PK\005\006" (empty ZIP) or "PK\007\008" (spanned [over several files])
         if (! hdrStr == "PK\003\004\024") {
-            stop(sprintf("File \"%s\" has not the correct file format (is not a ZIP archive).", basename(fleNme)));
+            stop(sprintf("File \"%s\" has not the correct file format (is not a ZIP archive).", basename(fleNme)))
         }
     }
     TRUE
 }
 
 chkVar <- function(dtaFrm = NULL, varNme = c()) {
-    if (is.null(varNme) || length(varNme) == 0 || !all(nzchar(varNme))) return(FALSE);
+    if (is.null(varNme) || length(varNme) == 0 || !all(nzchar(varNme))) return(FALSE)
     if (!all(varNme %in% names(dtaFrm))) {
-        stop(sprintf("The variable(s) %s are not contained in the current data set.", paste(varNme[! (varNme %in% names(dtaFrm))], collapse = ", ")));
+        stop(sprintf("The variable(s) %s are not contained in the current data set.", paste(varNme[! (varNme %in% names(dtaFrm))], collapse = ", ")))
     }
     TRUE
 }
@@ -222,11 +224,11 @@ fmtFlI <- function(fleInp = c(), minLng = 1, maxLng = Inf, excExt = "") {
     # if fleOut is empty, fleInp is used with its file extension replaced with ".omv"
     if (length(fleInp) < minLng || length(fleInp) > maxLng) {
         stop(sprintf("The fleInp-argument is supposed to be a character vector with a minimal length of %.0f and a maximal length of %.0f (current length is %.0f).%s",
-                     minLng, maxLng, length(fleInp), ifelse(length(fleInp) > maxLng, "\n  If you would like to process several files, call the function individually for each.", "")));
+                     minLng, maxLng, length(fleInp), ifelse(length(fleInp) > maxLng, "\n  If you would like to process several files, call the function individually for each.", "")))
     }
-    fleInp <- unname(sapply(fleInp, nrmFle));
-    all(sapply(fleInp, chkFle));
-    all(sapply(fleInp, chkExt, setdiff(vldExt, excExt)));
+    fleInp <- unname(sapply(fleInp, nrmFle))
+    all(sapply(fleInp, chkFle))
+    all(sapply(fleInp, chkExt, setdiff(vldExt, excExt)))
     fleInp
 }
 
@@ -236,7 +238,7 @@ fmtFlO <- function(fleOut = "", fleInp = "", rplExt = "") {
     } else if (length(fleInp) == 1 && nzchar(fleInp[1])) {
         sub(paste0(".", tools::file_ext(fleInp[1])), rplExt, fleInp[1])
     } else {
-        stop(paste0("Either fleOut needs to be given as a valid non-empty file name or a single entry in fleInp where the extension is replaced with: \"", rplExt, "\"."));
+        stop(paste0("Either fleOut needs to be given as a valid non-empty file name or a single entry in fleInp where the extension is replaced with: \"", rplExt, "\"."))
     }
 }
 
@@ -244,7 +246,7 @@ fmtFlO <- function(fleOut = "", fleInp = "", rplExt = "") {
 # get function arguments and adjust them / select those valid for the current function call
 
 adjArg <- function(fcnNme = c(), dflArg = list(), varArg = list(), fxdArg = c()) {
-    chgArg <- setdiff(intersect(fcnArg(fcnNme), names(varArg)), fxdArg);
+    chgArg <- setdiff(intersect(fcnArg(fcnNme), names(varArg)), fxdArg)
     c(dflArg[setdiff(names(dflArg), chgArg)], varArg[chgArg])
 }
 
@@ -254,7 +256,7 @@ fcnArg <- function(fcnNme = c()) {
     } else if (is.character(fcnNme) && length(fcnNme) == 2) {
         eval(parse(text = paste0("formalArgs(getS3method(\"", fcnNme[1], "\", \"", fcnNme[2], "\"))")))
     } else {
-        stop("The argument to fcnArg must be a character (vector) with 1 or 2 elements.");
+        stop("The argument to fcnArg must be a character (vector) with 1 or 2 elements.")
     }
 }
 
@@ -268,22 +270,26 @@ setAtt <- function(attLst = c(), inpObj = NULL, outObj = NULL) {
         # which contains the attribute in attNme (chkAtt), that are then stored in the mtaDta-
         # variable; the attribute might be empty (chkAtt == FALSE), and then the default is kept
         if        (is.list(outObj) && chkAtt(inpObj, attNme)) {
-            outObj[[attNme]] <- attr(inpObj, attNme);
+            outObj[[attNme]] <- attr(inpObj, attNme)
         # if the input object is the mtaDta-variable (which is a list), and the attribute is set in
         # the output object unless the attribute already exists in the ouput object (!chkAtt), then
         # it shouldn't be overwritten
         } else if (is.list(inpObj) && !chkAtt(outObj, attNme)) {
-            attr(outObj, attNme) <- inpObj[[attNme]];
+            attr(outObj, attNme) <- inpObj[[attNme]]
         # the case which is critical is if both input and output objects are lists (then the first
         # part of the if-conditions above - is.list - wouldn't work); the problem is that data
         # frames are both lists and data frames, and therefore an error is thrown if BOTH input
         # and output objects are lists but not data frames
         } else if (is.list(inpObj) && !is.data.frame(inpObj) && is.list(outObj) && !is.data.frame(outObj)) {
-            cat(paste0("attNme: ", attNme, "\n"));
-            cat(paste0("attLst: ", paste0(attLst, collapse = ", "), "\n\n"));
-            cat("inpObj:\n"); cat(utils::str(inpObj)); cat("\n\n");
-            cat("outObj:\n"); cat(utils::str(outObj)); cat("\n\n");
-            stop("Error when storing or accessing meta-data information. Please send the file causing the error to sebastian.jentschke@uib.no");
+            cat(paste0("attNme: ", attNme, "\n"))
+            cat(paste0("attLst: ", paste0(attLst, collapse = ", "), "\n\n"))
+            cat("inpObj:\n")
+            cat(utils::str(inpObj))
+            cat("\n\n")
+            cat("outObj:\n")
+            cat(utils::str(outObj))
+            cat("\n\n")
+            stop("Error when storing or accessing meta-data information. Please send the file causing the error to sebastian.jentschke@uib.no")
         }
     }
 
@@ -292,7 +298,7 @@ setAtt <- function(attLst = c(), inpObj = NULL, outObj = NULL) {
 
 rmvAtt <- function(attObj = NULL) {
     for (crrAtt in setdiff(names(attributes(attObj)), c("class", "comment", "dim", "jmv-id", "jmv-desc", "levels", "names", "row.names", "values"))) {
-        attr(attObj, crrAtt) <- NULL;
+        attr(attObj, crrAtt) <- NULL
     }
 
     attObj
